---
hide:
  - toc
---
# Scenarios

A Scenario is a starting place for a particular type of investigation. While each case is unique, 
many have common aspects and can be roughly grouped together. 

A Scenario is the highest-level grouping in DFIQ. A Scenario is made of one or more Facets 
(different "sides" of an investigation), which in turn are made up of investigative [Questions](/questions).
